"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._954 import StraightBevelGearDesign
    from ._955 import StraightBevelGearMeshDesign
    from ._956 import StraightBevelGearSetDesign
    from ._957 import StraightBevelMeshedGearDesign
