"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6607 import AbstractAssemblyCompoundCriticalSpeedAnalysis
    from ._6608 import AbstractShaftCompoundCriticalSpeedAnalysis
    from ._6609 import AbstractShaftOrHousingCompoundCriticalSpeedAnalysis
    from ._6610 import AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6611 import AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis
    from ._6612 import AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6613 import AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6614 import AssemblyCompoundCriticalSpeedAnalysis
    from ._6615 import BearingCompoundCriticalSpeedAnalysis
    from ._6616 import BeltConnectionCompoundCriticalSpeedAnalysis
    from ._6617 import BeltDriveCompoundCriticalSpeedAnalysis
    from ._6618 import BevelDifferentialGearCompoundCriticalSpeedAnalysis
    from ._6619 import BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis
    from ._6620 import BevelDifferentialGearSetCompoundCriticalSpeedAnalysis
    from ._6621 import BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis
    from ._6622 import BevelDifferentialSunGearCompoundCriticalSpeedAnalysis
    from ._6623 import BevelGearCompoundCriticalSpeedAnalysis
    from ._6624 import BevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6625 import BevelGearSetCompoundCriticalSpeedAnalysis
    from ._6626 import BoltCompoundCriticalSpeedAnalysis
    from ._6627 import BoltedJointCompoundCriticalSpeedAnalysis
    from ._6628 import ClutchCompoundCriticalSpeedAnalysis
    from ._6629 import ClutchConnectionCompoundCriticalSpeedAnalysis
    from ._6630 import ClutchHalfCompoundCriticalSpeedAnalysis
    from ._6631 import CoaxialConnectionCompoundCriticalSpeedAnalysis
    from ._6632 import ComponentCompoundCriticalSpeedAnalysis
    from ._6633 import ConceptCouplingCompoundCriticalSpeedAnalysis
    from ._6634 import ConceptCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6635 import ConceptCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6636 import ConceptGearCompoundCriticalSpeedAnalysis
    from ._6637 import ConceptGearMeshCompoundCriticalSpeedAnalysis
    from ._6638 import ConceptGearSetCompoundCriticalSpeedAnalysis
    from ._6639 import ConicalGearCompoundCriticalSpeedAnalysis
    from ._6640 import ConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6641 import ConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6642 import ConnectionCompoundCriticalSpeedAnalysis
    from ._6643 import ConnectorCompoundCriticalSpeedAnalysis
    from ._6644 import CouplingCompoundCriticalSpeedAnalysis
    from ._6645 import CouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6646 import CouplingHalfCompoundCriticalSpeedAnalysis
    from ._6647 import CVTBeltConnectionCompoundCriticalSpeedAnalysis
    from ._6648 import CVTCompoundCriticalSpeedAnalysis
    from ._6649 import CVTPulleyCompoundCriticalSpeedAnalysis
    from ._6650 import CycloidalAssemblyCompoundCriticalSpeedAnalysis
    from ._6651 import CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6652 import CycloidalDiscCompoundCriticalSpeedAnalysis
    from ._6653 import CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6654 import CylindricalGearCompoundCriticalSpeedAnalysis
    from ._6655 import CylindricalGearMeshCompoundCriticalSpeedAnalysis
    from ._6656 import CylindricalGearSetCompoundCriticalSpeedAnalysis
    from ._6657 import CylindricalPlanetGearCompoundCriticalSpeedAnalysis
    from ._6658 import DatumCompoundCriticalSpeedAnalysis
    from ._6659 import ExternalCADModelCompoundCriticalSpeedAnalysis
    from ._6660 import FaceGearCompoundCriticalSpeedAnalysis
    from ._6661 import FaceGearMeshCompoundCriticalSpeedAnalysis
    from ._6662 import FaceGearSetCompoundCriticalSpeedAnalysis
    from ._6663 import FEPartCompoundCriticalSpeedAnalysis
    from ._6664 import FlexiblePinAssemblyCompoundCriticalSpeedAnalysis
    from ._6665 import GearCompoundCriticalSpeedAnalysis
    from ._6666 import GearMeshCompoundCriticalSpeedAnalysis
    from ._6667 import GearSetCompoundCriticalSpeedAnalysis
    from ._6668 import GuideDxfModelCompoundCriticalSpeedAnalysis
    from ._6669 import HypoidGearCompoundCriticalSpeedAnalysis
    from ._6670 import HypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6671 import HypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6672 import InterMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6673 import KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis
    from ._6674 import KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6675 import KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6676 import KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis
    from ._6677 import KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6678 import KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6679 import KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6680 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6681 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6682 import MassDiscCompoundCriticalSpeedAnalysis
    from ._6683 import MeasurementComponentCompoundCriticalSpeedAnalysis
    from ._6684 import MountableComponentCompoundCriticalSpeedAnalysis
    from ._6685 import OilSealCompoundCriticalSpeedAnalysis
    from ._6686 import PartCompoundCriticalSpeedAnalysis
    from ._6687 import PartToPartShearCouplingCompoundCriticalSpeedAnalysis
    from ._6688 import PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6689 import PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6690 import PlanetaryConnectionCompoundCriticalSpeedAnalysis
    from ._6691 import PlanetaryGearSetCompoundCriticalSpeedAnalysis
    from ._6692 import PlanetCarrierCompoundCriticalSpeedAnalysis
    from ._6693 import PointLoadCompoundCriticalSpeedAnalysis
    from ._6694 import PowerLoadCompoundCriticalSpeedAnalysis
    from ._6695 import PulleyCompoundCriticalSpeedAnalysis
    from ._6696 import RingPinsCompoundCriticalSpeedAnalysis
    from ._6697 import RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis
    from ._6698 import RollingRingAssemblyCompoundCriticalSpeedAnalysis
    from ._6699 import RollingRingCompoundCriticalSpeedAnalysis
    from ._6700 import RollingRingConnectionCompoundCriticalSpeedAnalysis
    from ._6701 import RootAssemblyCompoundCriticalSpeedAnalysis
    from ._6702 import ShaftCompoundCriticalSpeedAnalysis
    from ._6703 import ShaftHubConnectionCompoundCriticalSpeedAnalysis
    from ._6704 import ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6705 import SpecialisedAssemblyCompoundCriticalSpeedAnalysis
    from ._6706 import SpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6707 import SpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6708 import SpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6709 import SpringDamperCompoundCriticalSpeedAnalysis
    from ._6710 import SpringDamperConnectionCompoundCriticalSpeedAnalysis
    from ._6711 import SpringDamperHalfCompoundCriticalSpeedAnalysis
    from ._6712 import StraightBevelDiffGearCompoundCriticalSpeedAnalysis
    from ._6713 import StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis
    from ._6714 import StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis
    from ._6715 import StraightBevelGearCompoundCriticalSpeedAnalysis
    from ._6716 import StraightBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6717 import StraightBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6718 import StraightBevelPlanetGearCompoundCriticalSpeedAnalysis
    from ._6719 import StraightBevelSunGearCompoundCriticalSpeedAnalysis
    from ._6720 import SynchroniserCompoundCriticalSpeedAnalysis
    from ._6721 import SynchroniserHalfCompoundCriticalSpeedAnalysis
    from ._6722 import SynchroniserPartCompoundCriticalSpeedAnalysis
    from ._6723 import SynchroniserSleeveCompoundCriticalSpeedAnalysis
    from ._6724 import TorqueConverterCompoundCriticalSpeedAnalysis
    from ._6725 import TorqueConverterConnectionCompoundCriticalSpeedAnalysis
    from ._6726 import TorqueConverterPumpCompoundCriticalSpeedAnalysis
    from ._6727 import TorqueConverterTurbineCompoundCriticalSpeedAnalysis
    from ._6728 import UnbalancedMassCompoundCriticalSpeedAnalysis
    from ._6729 import VirtualComponentCompoundCriticalSpeedAnalysis
    from ._6730 import WormGearCompoundCriticalSpeedAnalysis
    from ._6731 import WormGearMeshCompoundCriticalSpeedAnalysis
    from ._6732 import WormGearSetCompoundCriticalSpeedAnalysis
    from ._6733 import ZerolBevelGearCompoundCriticalSpeedAnalysis
    from ._6734 import ZerolBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6735 import ZerolBevelGearSetCompoundCriticalSpeedAnalysis
