"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._966 import KlingelnbergCycloPalloidSpiralBevelGearDesign
    from ._967 import KlingelnbergCycloPalloidSpiralBevelGearMeshDesign
    from ._968 import KlingelnbergCycloPalloidSpiralBevelGearSetDesign
    from ._969 import KlingelnbergCycloPalloidSpiralBevelMeshedGearDesign
