"""_445.py

AGMAScuffingResultsRow
"""


from mastapy._internal import constructor
from mastapy.gears.rating.cylindrical import _477
from mastapy._internal.python_net import python_net_import

_AGMA_SCUFFING_RESULTS_ROW = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical', 'AGMAScuffingResultsRow')


__docformat__ = 'restructuredtext en'
__all__ = ('AGMAScuffingResultsRow',)


class AGMAScuffingResultsRow(_477.ScuffingResultsRow):
    """AGMAScuffingResultsRow

    This is a mastapy class.
    """

    TYPE = _AGMA_SCUFFING_RESULTS_ROW

    def __init__(self, instance_to_wrap: 'AGMAScuffingResultsRow.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def central_film_thickness_isothermal(self) -> 'float':
        """float: 'CentralFilmThicknessIsothermal' is the original name of this property."""

        temp = self.wrapped.CentralFilmThicknessIsothermal

        if temp is None:
            return 0.0

        return temp

    @central_film_thickness_isothermal.setter
    def central_film_thickness_isothermal(self, value: 'float'):
        self.wrapped.CentralFilmThicknessIsothermal = float(value) if value is not None else 0.0

    @property
    def central_film_thickness_with_inlet_shear_heating(self) -> 'float':
        """float: 'CentralFilmThicknessWithInletShearHeating' is the original name of this property."""

        temp = self.wrapped.CentralFilmThicknessWithInletShearHeating

        if temp is None:
            return 0.0

        return temp

    @central_film_thickness_with_inlet_shear_heating.setter
    def central_film_thickness_with_inlet_shear_heating(self, value: 'float'):
        self.wrapped.CentralFilmThicknessWithInletShearHeating = float(value) if value is not None else 0.0

    @property
    def contact_temperature(self) -> 'float':
        """float: 'ContactTemperature' is the original name of this property."""

        temp = self.wrapped.ContactTemperature

        if temp is None:
            return 0.0

        return temp

    @contact_temperature.setter
    def contact_temperature(self, value: 'float'):
        self.wrapped.ContactTemperature = float(value) if value is not None else 0.0

    @property
    def dimensionless_central_film_thickness(self) -> 'float':
        """float: 'DimensionlessCentralFilmThickness' is the original name of this property."""

        temp = self.wrapped.DimensionlessCentralFilmThickness

        if temp is None:
            return 0.0

        return temp

    @dimensionless_central_film_thickness.setter
    def dimensionless_central_film_thickness(self, value: 'float'):
        self.wrapped.DimensionlessCentralFilmThickness = float(value) if value is not None else 0.0

    @property
    def flash_temperature(self) -> 'float':
        """float: 'FlashTemperature' is the original name of this property."""

        temp = self.wrapped.FlashTemperature

        if temp is None:
            return 0.0

        return temp

    @flash_temperature.setter
    def flash_temperature(self, value: 'float'):
        self.wrapped.FlashTemperature = float(value) if value is not None else 0.0

    @property
    def hertzian_stress(self) -> 'float':
        """float: 'HertzianStress' is the original name of this property."""

        temp = self.wrapped.HertzianStress

        if temp is None:
            return 0.0

        return temp

    @hertzian_stress.setter
    def hertzian_stress(self, value: 'float'):
        self.wrapped.HertzianStress = float(value) if value is not None else 0.0

    @property
    def load_parameter(self) -> 'float':
        """float: 'LoadParameter' is the original name of this property."""

        temp = self.wrapped.LoadParameter

        if temp is None:
            return 0.0

        return temp

    @load_parameter.setter
    def load_parameter(self, value: 'float'):
        self.wrapped.LoadParameter = float(value) if value is not None else 0.0

    @property
    def mean_coefficient_of_friction(self) -> 'float':
        """float: 'MeanCoefficientOfFriction' is the original name of this property."""

        temp = self.wrapped.MeanCoefficientOfFriction

        if temp is None:
            return 0.0

        return temp

    @mean_coefficient_of_friction.setter
    def mean_coefficient_of_friction(self, value: 'float'):
        self.wrapped.MeanCoefficientOfFriction = float(value) if value is not None else 0.0

    @property
    def pinion_rolling_velocity(self) -> 'float':
        """float: 'PinionRollingVelocity' is the original name of this property."""

        temp = self.wrapped.PinionRollingVelocity

        if temp is None:
            return 0.0

        return temp

    @pinion_rolling_velocity.setter
    def pinion_rolling_velocity(self, value: 'float'):
        self.wrapped.PinionRollingVelocity = float(value) if value is not None else 0.0

    @property
    def semi_width_of_hertzian_contact_band(self) -> 'float':
        """float: 'SemiWidthOfHertzianContactBand' is the original name of this property."""

        temp = self.wrapped.SemiWidthOfHertzianContactBand

        if temp is None:
            return 0.0

        return temp

    @semi_width_of_hertzian_contact_band.setter
    def semi_width_of_hertzian_contact_band(self, value: 'float'):
        self.wrapped.SemiWidthOfHertzianContactBand = float(value) if value is not None else 0.0

    @property
    def slideto_roll_ratio(self) -> 'float':
        """float: 'SlidetoRollRatio' is the original name of this property."""

        temp = self.wrapped.SlidetoRollRatio

        if temp is None:
            return 0.0

        return temp

    @slideto_roll_ratio.setter
    def slideto_roll_ratio(self, value: 'float'):
        self.wrapped.SlidetoRollRatio = float(value) if value is not None else 0.0

    @property
    def sliding_velocity(self) -> 'float':
        """float: 'SlidingVelocity' is the original name of this property."""

        temp = self.wrapped.SlidingVelocity

        if temp is None:
            return 0.0

        return temp

    @sliding_velocity.setter
    def sliding_velocity(self, value: 'float'):
        self.wrapped.SlidingVelocity = float(value) if value is not None else 0.0

    @property
    def specific_film_thickness_with_filter_cutoff_wave_length_isothermal(self) -> 'float':
        """float: 'SpecificFilmThicknessWithFilterCutoffWaveLengthIsothermal' is the original name of this property."""

        temp = self.wrapped.SpecificFilmThicknessWithFilterCutoffWaveLengthIsothermal

        if temp is None:
            return 0.0

        return temp

    @specific_film_thickness_with_filter_cutoff_wave_length_isothermal.setter
    def specific_film_thickness_with_filter_cutoff_wave_length_isothermal(self, value: 'float'):
        self.wrapped.SpecificFilmThicknessWithFilterCutoffWaveLengthIsothermal = float(value) if value is not None else 0.0

    @property
    def specific_film_thickness_with_filter_cutoff_wave_length_with_inlet_shear_heating(self) -> 'float':
        """float: 'SpecificFilmThicknessWithFilterCutoffWaveLengthWithInletShearHeating' is the original name of this property."""

        temp = self.wrapped.SpecificFilmThicknessWithFilterCutoffWaveLengthWithInletShearHeating

        if temp is None:
            return 0.0

        return temp

    @specific_film_thickness_with_filter_cutoff_wave_length_with_inlet_shear_heating.setter
    def specific_film_thickness_with_filter_cutoff_wave_length_with_inlet_shear_heating(self, value: 'float'):
        self.wrapped.SpecificFilmThicknessWithFilterCutoffWaveLengthWithInletShearHeating = float(value) if value is not None else 0.0

    @property
    def speed_parameter(self) -> 'float':
        """float: 'SpeedParameter' is the original name of this property."""

        temp = self.wrapped.SpeedParameter

        if temp is None:
            return 0.0

        return temp

    @speed_parameter.setter
    def speed_parameter(self, value: 'float'):
        self.wrapped.SpeedParameter = float(value) if value is not None else 0.0

    @property
    def thermal_loading_parameter(self) -> 'float':
        """float: 'ThermalLoadingParameter' is the original name of this property."""

        temp = self.wrapped.ThermalLoadingParameter

        if temp is None:
            return 0.0

        return temp

    @thermal_loading_parameter.setter
    def thermal_loading_parameter(self, value: 'float'):
        self.wrapped.ThermalLoadingParameter = float(value) if value is not None else 0.0

    @property
    def thermal_reduction_factor(self) -> 'float':
        """float: 'ThermalReductionFactor' is the original name of this property."""

        temp = self.wrapped.ThermalReductionFactor

        if temp is None:
            return 0.0

        return temp

    @thermal_reduction_factor.setter
    def thermal_reduction_factor(self, value: 'float'):
        self.wrapped.ThermalReductionFactor = float(value) if value is not None else 0.0

    @property
    def wheel_rolling_velocity(self) -> 'float':
        """float: 'WheelRollingVelocity' is the original name of this property."""

        temp = self.wrapped.WheelRollingVelocity

        if temp is None:
            return 0.0

        return temp

    @wheel_rolling_velocity.setter
    def wheel_rolling_velocity(self, value: 'float'):
        self.wrapped.WheelRollingVelocity = float(value) if value is not None else 0.0
