"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2802 import AbstractAssemblyCompoundSystemDeflection
    from ._2803 import AbstractShaftCompoundSystemDeflection
    from ._2804 import AbstractShaftOrHousingCompoundSystemDeflection
    from ._2805 import AbstractShaftToMountableComponentConnectionCompoundSystemDeflection
    from ._2806 import AGMAGleasonConicalGearCompoundSystemDeflection
    from ._2807 import AGMAGleasonConicalGearMeshCompoundSystemDeflection
    from ._2808 import AGMAGleasonConicalGearSetCompoundSystemDeflection
    from ._2809 import AssemblyCompoundSystemDeflection
    from ._2810 import BearingCompoundSystemDeflection
    from ._2811 import BeltConnectionCompoundSystemDeflection
    from ._2812 import BeltDriveCompoundSystemDeflection
    from ._2813 import BevelDifferentialGearCompoundSystemDeflection
    from ._2814 import BevelDifferentialGearMeshCompoundSystemDeflection
    from ._2815 import BevelDifferentialGearSetCompoundSystemDeflection
    from ._2816 import BevelDifferentialPlanetGearCompoundSystemDeflection
    from ._2817 import BevelDifferentialSunGearCompoundSystemDeflection
    from ._2818 import BevelGearCompoundSystemDeflection
    from ._2819 import BevelGearMeshCompoundSystemDeflection
    from ._2820 import BevelGearSetCompoundSystemDeflection
    from ._2821 import BoltCompoundSystemDeflection
    from ._2822 import BoltedJointCompoundSystemDeflection
    from ._2823 import ClutchCompoundSystemDeflection
    from ._2824 import ClutchConnectionCompoundSystemDeflection
    from ._2825 import ClutchHalfCompoundSystemDeflection
    from ._2826 import CoaxialConnectionCompoundSystemDeflection
    from ._2827 import ComponentCompoundSystemDeflection
    from ._2828 import ConceptCouplingCompoundSystemDeflection
    from ._2829 import ConceptCouplingConnectionCompoundSystemDeflection
    from ._2830 import ConceptCouplingHalfCompoundSystemDeflection
    from ._2831 import ConceptGearCompoundSystemDeflection
    from ._2832 import ConceptGearMeshCompoundSystemDeflection
    from ._2833 import ConceptGearSetCompoundSystemDeflection
    from ._2834 import ConicalGearCompoundSystemDeflection
    from ._2835 import ConicalGearMeshCompoundSystemDeflection
    from ._2836 import ConicalGearSetCompoundSystemDeflection
    from ._2837 import ConnectionCompoundSystemDeflection
    from ._2838 import ConnectorCompoundSystemDeflection
    from ._2839 import CouplingCompoundSystemDeflection
    from ._2840 import CouplingConnectionCompoundSystemDeflection
    from ._2841 import CouplingHalfCompoundSystemDeflection
    from ._2842 import CVTBeltConnectionCompoundSystemDeflection
    from ._2843 import CVTCompoundSystemDeflection
    from ._2844 import CVTPulleyCompoundSystemDeflection
    from ._2845 import CycloidalAssemblyCompoundSystemDeflection
    from ._2846 import CycloidalDiscCentralBearingConnectionCompoundSystemDeflection
    from ._2847 import CycloidalDiscCompoundSystemDeflection
    from ._2848 import CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection
    from ._2849 import CylindricalGearCompoundSystemDeflection
    from ._2850 import CylindricalGearMeshCompoundSystemDeflection
    from ._2851 import CylindricalGearSetCompoundSystemDeflection
    from ._2852 import CylindricalPlanetGearCompoundSystemDeflection
    from ._2853 import DatumCompoundSystemDeflection
    from ._2854 import DutyCycleEfficiencyResults
    from ._2855 import ExternalCADModelCompoundSystemDeflection
    from ._2856 import FaceGearCompoundSystemDeflection
    from ._2857 import FaceGearMeshCompoundSystemDeflection
    from ._2858 import FaceGearSetCompoundSystemDeflection
    from ._2859 import FEPartCompoundSystemDeflection
    from ._2860 import FlexiblePinAssemblyCompoundSystemDeflection
    from ._2861 import GearCompoundSystemDeflection
    from ._2862 import GearMeshCompoundSystemDeflection
    from ._2863 import GearSetCompoundSystemDeflection
    from ._2864 import GuideDxfModelCompoundSystemDeflection
    from ._2865 import HypoidGearCompoundSystemDeflection
    from ._2866 import HypoidGearMeshCompoundSystemDeflection
    from ._2867 import HypoidGearSetCompoundSystemDeflection
    from ._2868 import InterMountableComponentConnectionCompoundSystemDeflection
    from ._2869 import KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection
    from ._2870 import KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection
    from ._2871 import KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection
    from ._2872 import KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection
    from ._2873 import KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection
    from ._2874 import KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection
    from ._2875 import KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection
    from ._2876 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection
    from ._2877 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection
    from ._2878 import MassDiscCompoundSystemDeflection
    from ._2879 import MeasurementComponentCompoundSystemDeflection
    from ._2880 import MountableComponentCompoundSystemDeflection
    from ._2881 import OilSealCompoundSystemDeflection
    from ._2882 import PartCompoundSystemDeflection
    from ._2883 import PartToPartShearCouplingCompoundSystemDeflection
    from ._2884 import PartToPartShearCouplingConnectionCompoundSystemDeflection
    from ._2885 import PartToPartShearCouplingHalfCompoundSystemDeflection
    from ._2886 import PlanetaryConnectionCompoundSystemDeflection
    from ._2887 import PlanetaryGearSetCompoundSystemDeflection
    from ._2888 import PlanetCarrierCompoundSystemDeflection
    from ._2889 import PointLoadCompoundSystemDeflection
    from ._2890 import PowerLoadCompoundSystemDeflection
    from ._2891 import PulleyCompoundSystemDeflection
    from ._2892 import RingPinsCompoundSystemDeflection
    from ._2893 import RingPinsToDiscConnectionCompoundSystemDeflection
    from ._2894 import RollingRingAssemblyCompoundSystemDeflection
    from ._2895 import RollingRingCompoundSystemDeflection
    from ._2896 import RollingRingConnectionCompoundSystemDeflection
    from ._2897 import RootAssemblyCompoundSystemDeflection
    from ._2898 import ShaftCompoundSystemDeflection
    from ._2899 import ShaftDutyCycleSystemDeflection
    from ._2900 import ShaftHubConnectionCompoundSystemDeflection
    from ._2901 import ShaftToMountableComponentConnectionCompoundSystemDeflection
    from ._2902 import SpecialisedAssemblyCompoundSystemDeflection
    from ._2903 import SpiralBevelGearCompoundSystemDeflection
    from ._2904 import SpiralBevelGearMeshCompoundSystemDeflection
    from ._2905 import SpiralBevelGearSetCompoundSystemDeflection
    from ._2906 import SpringDamperCompoundSystemDeflection
    from ._2907 import SpringDamperConnectionCompoundSystemDeflection
    from ._2908 import SpringDamperHalfCompoundSystemDeflection
    from ._2909 import StraightBevelDiffGearCompoundSystemDeflection
    from ._2910 import StraightBevelDiffGearMeshCompoundSystemDeflection
    from ._2911 import StraightBevelDiffGearSetCompoundSystemDeflection
    from ._2912 import StraightBevelGearCompoundSystemDeflection
    from ._2913 import StraightBevelGearMeshCompoundSystemDeflection
    from ._2914 import StraightBevelGearSetCompoundSystemDeflection
    from ._2915 import StraightBevelPlanetGearCompoundSystemDeflection
    from ._2916 import StraightBevelSunGearCompoundSystemDeflection
    from ._2917 import SynchroniserCompoundSystemDeflection
    from ._2918 import SynchroniserHalfCompoundSystemDeflection
    from ._2919 import SynchroniserPartCompoundSystemDeflection
    from ._2920 import SynchroniserSleeveCompoundSystemDeflection
    from ._2921 import TorqueConverterCompoundSystemDeflection
    from ._2922 import TorqueConverterConnectionCompoundSystemDeflection
    from ._2923 import TorqueConverterPumpCompoundSystemDeflection
    from ._2924 import TorqueConverterTurbineCompoundSystemDeflection
    from ._2925 import UnbalancedMassCompoundSystemDeflection
    from ._2926 import VirtualComponentCompoundSystemDeflection
    from ._2927 import WormGearCompoundSystemDeflection
    from ._2928 import WormGearMeshCompoundSystemDeflection
    from ._2929 import WormGearSetCompoundSystemDeflection
    from ._2930 import ZerolBevelGearCompoundSystemDeflection
    from ._2931 import ZerolBevelGearMeshCompoundSystemDeflection
    from ._2932 import ZerolBevelGearSetCompoundSystemDeflection
