"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._958 import StraightBevelDiffGearDesign
    from ._959 import StraightBevelDiffGearMeshDesign
    from ._960 import StraightBevelDiffGearSetDesign
    from ._961 import StraightBevelDiffMeshedGearDesign
