"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6476 import AbstractAssemblyCriticalSpeedAnalysis
    from ._6477 import AbstractShaftCriticalSpeedAnalysis
    from ._6478 import AbstractShaftOrHousingCriticalSpeedAnalysis
    from ._6479 import AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis
    from ._6480 import AGMAGleasonConicalGearCriticalSpeedAnalysis
    from ._6481 import AGMAGleasonConicalGearMeshCriticalSpeedAnalysis
    from ._6482 import AGMAGleasonConicalGearSetCriticalSpeedAnalysis
    from ._6483 import AssemblyCriticalSpeedAnalysis
    from ._6484 import BearingCriticalSpeedAnalysis
    from ._6485 import BeltConnectionCriticalSpeedAnalysis
    from ._6486 import BeltDriveCriticalSpeedAnalysis
    from ._6487 import BevelDifferentialGearCriticalSpeedAnalysis
    from ._6488 import BevelDifferentialGearMeshCriticalSpeedAnalysis
    from ._6489 import BevelDifferentialGearSetCriticalSpeedAnalysis
    from ._6490 import BevelDifferentialPlanetGearCriticalSpeedAnalysis
    from ._6491 import BevelDifferentialSunGearCriticalSpeedAnalysis
    from ._6492 import BevelGearCriticalSpeedAnalysis
    from ._6493 import BevelGearMeshCriticalSpeedAnalysis
    from ._6494 import BevelGearSetCriticalSpeedAnalysis
    from ._6495 import BoltCriticalSpeedAnalysis
    from ._6496 import BoltedJointCriticalSpeedAnalysis
    from ._6497 import ClutchConnectionCriticalSpeedAnalysis
    from ._6498 import ClutchCriticalSpeedAnalysis
    from ._6499 import ClutchHalfCriticalSpeedAnalysis
    from ._6500 import CoaxialConnectionCriticalSpeedAnalysis
    from ._6501 import ComponentCriticalSpeedAnalysis
    from ._6502 import ConceptCouplingConnectionCriticalSpeedAnalysis
    from ._6503 import ConceptCouplingCriticalSpeedAnalysis
    from ._6504 import ConceptCouplingHalfCriticalSpeedAnalysis
    from ._6505 import ConceptGearCriticalSpeedAnalysis
    from ._6506 import ConceptGearMeshCriticalSpeedAnalysis
    from ._6507 import ConceptGearSetCriticalSpeedAnalysis
    from ._6508 import ConicalGearCriticalSpeedAnalysis
    from ._6509 import ConicalGearMeshCriticalSpeedAnalysis
    from ._6510 import ConicalGearSetCriticalSpeedAnalysis
    from ._6511 import ConnectionCriticalSpeedAnalysis
    from ._6512 import ConnectorCriticalSpeedAnalysis
    from ._6513 import CouplingConnectionCriticalSpeedAnalysis
    from ._6514 import CouplingCriticalSpeedAnalysis
    from ._6515 import CouplingHalfCriticalSpeedAnalysis
    from ._2581 import CriticalSpeedAnalysis
    from ._6516 import CriticalSpeedAnalysisDrawStyle
    from ._6517 import CriticalSpeedAnalysisOptions
    from ._6518 import CVTBeltConnectionCriticalSpeedAnalysis
    from ._6519 import CVTCriticalSpeedAnalysis
    from ._6520 import CVTPulleyCriticalSpeedAnalysis
    from ._6521 import CycloidalAssemblyCriticalSpeedAnalysis
    from ._6522 import CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis
    from ._6523 import CycloidalDiscCriticalSpeedAnalysis
    from ._6524 import CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis
    from ._6525 import CylindricalGearCriticalSpeedAnalysis
    from ._6526 import CylindricalGearMeshCriticalSpeedAnalysis
    from ._6527 import CylindricalGearSetCriticalSpeedAnalysis
    from ._6528 import CylindricalPlanetGearCriticalSpeedAnalysis
    from ._6529 import DatumCriticalSpeedAnalysis
    from ._6530 import ExternalCADModelCriticalSpeedAnalysis
    from ._6531 import FaceGearCriticalSpeedAnalysis
    from ._6532 import FaceGearMeshCriticalSpeedAnalysis
    from ._6533 import FaceGearSetCriticalSpeedAnalysis
    from ._6534 import FEPartCriticalSpeedAnalysis
    from ._6535 import FlexiblePinAssemblyCriticalSpeedAnalysis
    from ._6536 import GearCriticalSpeedAnalysis
    from ._6537 import GearMeshCriticalSpeedAnalysis
    from ._6538 import GearSetCriticalSpeedAnalysis
    from ._6539 import GuideDxfModelCriticalSpeedAnalysis
    from ._6540 import HypoidGearCriticalSpeedAnalysis
    from ._6541 import HypoidGearMeshCriticalSpeedAnalysis
    from ._6542 import HypoidGearSetCriticalSpeedAnalysis
    from ._6543 import InterMountableComponentConnectionCriticalSpeedAnalysis
    from ._6544 import KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis
    from ._6545 import KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis
    from ._6546 import KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis
    from ._6547 import KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis
    from ._6548 import KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis
    from ._6549 import KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis
    from ._6550 import KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis
    from ._6551 import KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis
    from ._6552 import KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis
    from ._6553 import MassDiscCriticalSpeedAnalysis
    from ._6554 import MeasurementComponentCriticalSpeedAnalysis
    from ._6555 import MountableComponentCriticalSpeedAnalysis
    from ._6556 import OilSealCriticalSpeedAnalysis
    from ._6557 import PartCriticalSpeedAnalysis
    from ._6558 import PartToPartShearCouplingConnectionCriticalSpeedAnalysis
    from ._6559 import PartToPartShearCouplingCriticalSpeedAnalysis
    from ._6560 import PartToPartShearCouplingHalfCriticalSpeedAnalysis
    from ._6561 import PlanetaryConnectionCriticalSpeedAnalysis
    from ._6562 import PlanetaryGearSetCriticalSpeedAnalysis
    from ._6563 import PlanetCarrierCriticalSpeedAnalysis
    from ._6564 import PointLoadCriticalSpeedAnalysis
    from ._6565 import PowerLoadCriticalSpeedAnalysis
    from ._6566 import PulleyCriticalSpeedAnalysis
    from ._6567 import RingPinsCriticalSpeedAnalysis
    from ._6568 import RingPinsToDiscConnectionCriticalSpeedAnalysis
    from ._6569 import RollingRingAssemblyCriticalSpeedAnalysis
    from ._6570 import RollingRingConnectionCriticalSpeedAnalysis
    from ._6571 import RollingRingCriticalSpeedAnalysis
    from ._6572 import RootAssemblyCriticalSpeedAnalysis
    from ._6573 import ShaftCriticalSpeedAnalysis
    from ._6574 import ShaftHubConnectionCriticalSpeedAnalysis
    from ._6575 import ShaftToMountableComponentConnectionCriticalSpeedAnalysis
    from ._6576 import SpecialisedAssemblyCriticalSpeedAnalysis
    from ._6577 import SpiralBevelGearCriticalSpeedAnalysis
    from ._6578 import SpiralBevelGearMeshCriticalSpeedAnalysis
    from ._6579 import SpiralBevelGearSetCriticalSpeedAnalysis
    from ._6580 import SpringDamperConnectionCriticalSpeedAnalysis
    from ._6581 import SpringDamperCriticalSpeedAnalysis
    from ._6582 import SpringDamperHalfCriticalSpeedAnalysis
    from ._6583 import StraightBevelDiffGearCriticalSpeedAnalysis
    from ._6584 import StraightBevelDiffGearMeshCriticalSpeedAnalysis
    from ._6585 import StraightBevelDiffGearSetCriticalSpeedAnalysis
    from ._6586 import StraightBevelGearCriticalSpeedAnalysis
    from ._6587 import StraightBevelGearMeshCriticalSpeedAnalysis
    from ._6588 import StraightBevelGearSetCriticalSpeedAnalysis
    from ._6589 import StraightBevelPlanetGearCriticalSpeedAnalysis
    from ._6590 import StraightBevelSunGearCriticalSpeedAnalysis
    from ._6591 import SynchroniserCriticalSpeedAnalysis
    from ._6592 import SynchroniserHalfCriticalSpeedAnalysis
    from ._6593 import SynchroniserPartCriticalSpeedAnalysis
    from ._6594 import SynchroniserSleeveCriticalSpeedAnalysis
    from ._6595 import TorqueConverterConnectionCriticalSpeedAnalysis
    from ._6596 import TorqueConverterCriticalSpeedAnalysis
    from ._6597 import TorqueConverterPumpCriticalSpeedAnalysis
    from ._6598 import TorqueConverterTurbineCriticalSpeedAnalysis
    from ._6599 import UnbalancedMassCriticalSpeedAnalysis
    from ._6600 import VirtualComponentCriticalSpeedAnalysis
    from ._6601 import WormGearCriticalSpeedAnalysis
    from ._6602 import WormGearMeshCriticalSpeedAnalysis
    from ._6603 import WormGearSetCriticalSpeedAnalysis
    from ._6604 import ZerolBevelGearCriticalSpeedAnalysis
    from ._6605 import ZerolBevelGearMeshCriticalSpeedAnalysis
    from ._6606 import ZerolBevelGearSetCriticalSpeedAnalysis
