"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._5600 import AbstractDesignStateLoadCaseGroup
    from ._5601 import AbstractLoadCaseGroup
    from ._5602 import AbstractStaticLoadCaseGroup
    from ._5603 import ClutchEngagementStatus
    from ._5604 import ConceptSynchroGearEngagementStatus
    from ._5605 import DesignState
    from ._5606 import DutyCycle
    from ._5607 import GenericClutchEngagementStatus
    from ._5608 import LoadCaseGroupHistograms
    from ._5609 import SubGroupInSingleDesignState
    from ._5610 import SystemOptimisationGearSet
    from ._5611 import SystemOptimiserGearSetOptimisation
    from ._5612 import SystemOptimiserTargets
    from ._5613 import TimeSeriesLoadCaseGroup
