"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1355 import CustomSplineHalfDesign
    from ._1356 import CustomSplineJointDesign
    from ._1357 import DetailedSplineJointSettings
    from ._1358 import DIN5480SplineHalfDesign
    from ._1359 import DIN5480SplineJointDesign
    from ._1360 import DudleyEffectiveLengthApproximationOption
    from ._1361 import FitTypes
    from ._1362 import GBT3478SplineHalfDesign
    from ._1363 import GBT3478SplineJointDesign
    from ._1364 import HeatTreatmentTypes
    from ._1365 import ISO4156SplineHalfDesign
    from ._1366 import ISO4156SplineJointDesign
    from ._1367 import JISB1603SplineJointDesign
    from ._1368 import ManufacturingTypes
    from ._1369 import Modules
    from ._1370 import PressureAngleTypes
    from ._1371 import RootTypes
    from ._1372 import SAEFatigueLifeFactorTypes
    from ._1373 import SAESplineHalfDesign
    from ._1374 import SAESplineJointDesign
    from ._1375 import SAETorqueCycles
    from ._1376 import SplineDesignTypes
    from ._1377 import FinishingMethods
    from ._1378 import SplineFitClassType
    from ._1379 import SplineFixtureTypes
    from ._1380 import SplineHalfDesign
    from ._1381 import SplineJointDesign
    from ._1382 import SplineMaterial
    from ._1383 import SplineRatingTypes
    from ._1384 import SplineToleranceClassTypes
    from ._1385 import StandardSplineHalfDesign
    from ._1386 import StandardSplineJointDesign
