"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._991 import AddendumModificationDistributionRule
    from ._992 import BacklashSpecification
    from ._993 import BasicRackProfiles
    from ._994 import CaseHardeningProperties
    from ._995 import CreateNewSuitableCutterOption
    from ._996 import CrossedAxisCylindricalGearPair
    from ._997 import CrossedAxisCylindricalGearPairLineContact
    from ._998 import CrossedAxisCylindricalGearPairPointContact
    from ._999 import CylindricalGearAbstractRack
    from ._1000 import CylindricalGearAbstractRackFlank
    from ._1001 import CylindricalGearBasicRack
    from ._1002 import CylindricalGearBasicRackFlank
    from ._1003 import CylindricalGearCuttingOptions
    from ._1004 import CylindricalGearDefaults
    from ._1005 import CylindricalGearDesign
    from ._1006 import CylindricalGearDesignConstraint
    from ._1007 import CylindricalGearDesignConstraints
    from ._1008 import CylindricalGearDesignConstraintsDatabase
    from ._1009 import CylindricalGearDesignConstraintSettings
    from ._1010 import CylindricalGearFlankDesign
    from ._1011 import CylindricalGearMeshDesign
    from ._1012 import CylindricalGearMeshFlankDesign
    from ._1013 import CylindricalGearMicroGeometrySettings
    from ._1014 import CylindricalGearMicroGeometrySettingsDatabase
    from ._1015 import CylindricalGearMicroGeometrySettingsItem
    from ._1016 import CylindricalGearPinionTypeCutter
    from ._1017 import CylindricalGearPinionTypeCutterFlank
    from ._1018 import CylindricalGearProfileMeasurement
    from ._1019 import CylindricalGearProfileMeasurementType
    from ._1020 import CylindricalGearProfileModifications
    from ._1021 import CylindricalGearSetDesign
    from ._1022 import CylindricalGearSetFlankDesign
    from ._1023 import CylindricalGearSetMacroGeometryOptimiser
    from ._1024 import CylindricalGearSetManufacturingConfigurationSelection
    from ._1025 import CylindricalGearSetMicroGeometrySettings
    from ._1026 import CylindricalGearTableMGItemDetail
    from ._1027 import CylindricalGearTableWithMGCharts
    from ._1028 import CylindricalGearToothThicknessSpecification
    from ._1029 import CylindricalMeshAngularBacklash
    from ._1030 import CylindricalMeshedGear
    from ._1031 import CylindricalMeshedGearFlank
    from ._1032 import CylindricalMeshLinearBacklashSpecification
    from ._1033 import CylindricalPlanetaryGearSetDesign
    from ._1034 import CylindricalPlanetGearDesign
    from ._1035 import DIN3967AllowanceSeries
    from ._1036 import DIN3967ToleranceSeries
    from ._1037 import DoubleAxisScaleAndRange
    from ._1038 import FinishToothThicknessDesignSpecification
    from ._1039 import GearFitSystems
    from ._1040 import GearManufacturingConfigSetupViewModel
    from ._1041 import GearSetManufacturingConfigurationSetup
    from ._1042 import GeometrySpecificationType
    from ._1043 import HardenedMaterialProperties
    from ._1044 import HardnessProfileCalculationMethod
    from ._1045 import HeatTreatmentType
    from ._1046 import ISO6336Geometry
    from ._1047 import ISO6336GeometryBase
    from ._1048 import ISO6336GeometryForShapedGears
    from ._1049 import ISO6336GeometryManufactured
    from ._1050 import LinearBacklashSepcification
    from ._1051 import LTCALoadCaseModifiableSettings
    from ._1052 import LtcaSettings
    from ._1053 import MicroGeometryConvention
    from ._1054 import MicroGeometryProfileConvention
    from ._1055 import Micropitting
    from ._1056 import NamedPlanetAssemblyIndex
    from ._1057 import NamedPlanetSideBandAmplitudeFactor
    from ._1058 import ReadonlyToothThicknessSpecification
    from ._1059 import RelativeMeasurementViewModel
    from ._1060 import RelativeValuesSpecification
    from ._1061 import RootStressSurfaceChartOption
    from ._1062 import Scuffing
    from ._1063 import ScuffingCoefficientOfFrictionMethods
    from ._1064 import ScuffingTemperatureMethodsAGMA
    from ._1065 import ScuffingTemperatureMethodsISO
    from ._1066 import ShaperEdgeTypes
    from ._1067 import SpurGearLoadSharingCodes
    from ._1068 import StandardRack
    from ._1069 import StandardRackFlank
    from ._1070 import SurfaceRoughness
    from ._1071 import ThicknessType
    from ._1072 import TiffAnalysisSettings
    from ._1073 import TipAlterationCoefficientMethod
    from ._1074 import TolerancedMetalMeasurements
    from ._1075 import TolerancedValueSpecification
    from ._1076 import ToothFlankFractureAnalysisSettings
    from ._1077 import ToothThicknessSpecification
    from ._1078 import ToothThicknessSpecificationBase
    from ._1079 import TypeOfMechanismHousing
    from ._1080 import Usage
